@@ -26,7 +26,7 @@ for shader in "$SOURCE_DIR"*.frag; do
         output_path="$DEST_DIR$shader_name.frag.qsb"
 
         # Construct and run the qsb command.
-        qsb --qt6 -o "$output_path" "$shader"
+        /usr/lib/qt6/bin/qsb --qt6 -o "$output_path" "$shader"
 
         # Print a message to confirm compilation.
         echo "Compiled $shader to $output_path"
